@@ -42,23 +42,20 @@
 int main(int argc, char *argv[]) {
   const long samples=1000000l;          // total number of points in square
   long in=0l;                           // number of points in circle
-  // distribute workload over all processes
-#pragma omp parallel 
+  // distribute workload over all processes and make a global reduction 
+#pragma omp parallel reduction(+:in)
   {
     trng::yarn2 r;                      // random number engine
     int size=omp_get_num_threads();     // get total number of processes 
     int rank=omp_get_thread_num();      // get rank of current process
     trng::uniform01_dist<> u;           // random number distribution
     r.jump(2*(rank*samples/size));      // jump ahead
-    long in_local=0l;
     // throw random points into square 
     for (long i=rank*samples/size; i<(rank+1)*samples/size; ++i) {
       double x=u(r), y=u(r);            // choose random x- and y-coordinates
       if (x*x+y*y<=1.0)                 // is point in circle?
-	++in_local;                     // increase thread-local counter
+	++in;                           // increase thread-local counter
     }
-#pragma omp critical
-    in+=in_local;                       // increase global counter
   }
   // print result
   std::cout << "pi = " << 4.0*in/samples << std::endl;
