@@ -1,4 +1,4 @@
-// Copyright (c) 2000-2010, Heiko Bauke
+// Copyright (c) 2000-2011, Heiko Bauke
 // All rights reserved.
 // 
 // Redistribution and use in source and binary forms, with or without
@@ -54,8 +54,10 @@ namespace trng {
     typedef unsigned long long result_type;
     TRNG_CUDA_ENABLE
     result_type operator()() const;
-    static const result_type min=0;
-    static const result_type max=18446744073709551615ull;
+    static const result_type min_=0;
+    static const result_type max_=18446744073709551615ull;
+    static const result_type min=min_;
+    static const result_type max=max_;
   private:
     // compute floor(log_2(x))
     TRNG_CUDA_ENABLE
