@@ -1,4 +1,4 @@
-// Copyright (c) 2000-2010, Heiko Bauke
+// Copyright (c) 2000-2011, Heiko Bauke
 // All rights reserved.
 // 
 // Redistribution and use in source and binary forms, with or without
@@ -51,8 +51,8 @@ namespace trng {
     // Uniform random number generator concept
     typedef unsigned long result_type;
     result_type operator()() const;  
-    static const result_type min=1ul;
-    static const result_type max=2147483646ul;
+    static const result_type min_=1ul;
+    static const result_type max_=2147483646ul;
 
     // Parameter and status classes
     class status_type;
